# `primitive_metadata`
> note: unstable and subject to wild change, tho with intent to settle

some tools for writing and working with small-ish chunks of metadata
as [rdf](https://www.w3.org/TR/rdf11-primer/) in [python](https://python.org)

(for python 3.7+)

## `primitive_rdf`
`primitive_metadata.primitive_rdf` contains suggestions and utilities for expressing
rdf metadata with (almost entirely) built-in python data structures (`dict` and `set`)

## running unit tests
`python3 -m unittest`

## todo list
- write a readme
